local allEnemies

function addEnemy(x,y)
	enemy = {}
	enemy.isHit = false
	enemy.body = love.physics.newBody(world, x, y, "dynamic")
	enemy.shape = love.physics.newRectangleShape(50, 100)
	enemy.fixture = love.physics.newFixture(enemy.body, enemy.shape)
	enemy.fixture:setUserData("Enemy")

	table.insert(allEnemies, enemy)
end

function love.load()	
	windowWidth = love.graphics.getWidth()
	windowHeight = love.graphics.getHeight()

	love.physics.setMeter(64)
	world = love.physics.newWorld(0, 9.81*64, true)
	world:setCallbacks(beginContact, endContact)

	allEnemies = {}

	player = {}
	player.isHit = false
	player.canMove = true
	player.jumps = 2
	player.body = love.physics.newBody(world, windowWidth/2, 0, "dynamic")
	player.shape = love.physics.newRectangleShape(50, 100) --make a rectangle with a width of 650 and a height of 50
	player.fixture = love.physics.newFixture(player.body, player.shape) --attach shape to body
	player.body:setFixedRotation(true)
	player.fixture:setRestitution(0.1)
	player.fixture:setUserData("Player")

	borders = {}
	borders.ground = {}
	borders.ground.body = love.physics.newBody(world, windowWidth/2, windowHeight-25, "static")
	borders.ground.shape = love.physics.newRectangleShape(windowWidth, 50)
	borders.ground.fixture = love.physics.newFixture(borders.ground.body, borders.ground.shape)
	borders.ground.fixture:setUserData("Ground")

	love.graphics.setBackgroundColor(0.5, 0.5, 0.5, 1)

	addEnemy(100, 0)
	addEnemy(200, 0)
	addEnemy(300, 0)

end

function love.draw()
	love.graphics.setColor(1, 1, 1, 1)
 	love.graphics.polygon("fill", borders.ground.body:getWorldPoints(borders.ground.shape:getPoints()))

	love.graphics.polygon("fill", player.body:getWorldPoints(player.shape:getPoints()))

	love.graphics.setColor(1, 0, 0, 1)
	for _, enemy in ipairs(allEnemies) do
		if enemy.body:isDestroyed() == false then
			love.graphics.polygon("fill", enemy.body:getWorldPoints(enemy.shape:getPoints()))
		end
	end
end

function love.update(dt)
	world:update(dt)

	velX, velY = player.body:getLinearVelocity()

	if player.canMove == true then
		if love.keyboard.isDown("d") then
			player.body:applyForce(400, 0)
		elseif love.keyboard.isDown("a") then
			player.body:applyForce(-400, 0)
		end
	end

	if player.isHit then
		player.canMove = false
		player.body:setAngle(math.rad(90))
	end
end


function love.keypressed(key)
	if key == "escape" then
		love.event.quit()
	end

	if player.canMove == true then
		if key == "w" and player.jumps > 0 then
			player.body:applyLinearImpulse(0, -700)
			player.jumps = player.jumps - 1
		end

		if key == "s" then
			player.body:applyLinearImpulse(0, 2500)
		end
	end

end

function beginContact(a, b, coll)
	if a:getUserData() == "Player" and b:getUserData() == "Ground" or a:getUserData() == "Ground" and b:getUserData() == "Player" then
		player.jumps = 2
	end

	for _, enemy in ipairs(allEnemies) do
		if a:getUserData() == "Player" and b:getUserData() == "Enemy" and velY >= 1000 or a:getUserData() == "Enemy" and b:getUserData() == "Player" and velY >= 1000 then
			player.jumps = 2
			enemy.isHit = true
			enemy.body:destroy()
		end

		if a:getUserData() == "Player" and b:getUserData() == "Enemy" and velY <= 1000 or a:getUserData() == "Enemy" and b:getUserData() == "Player" and velY <= 1000 then
			player.isHit = true
		end
	end

end

function endContact(a, b, coll)
	if a:getUserData() == "Player" and b:getUserData() == "Ground" or a:getUserData() == "Ground" and b:getUserData() == "Player" then
		
	end
end